from mediathequeroubaix.app import app
from mediathequeroubaix.config import APP_NAME

# Support calling using `python -m`
# https://typer.tiangolo.com/tutorial/package/#support-python-m-optional
app(APP_NAME)
